@@ -1,9 +1,10 @@
 from __future__ import annotations
 
 from copy import deepcopy
-from dataclasses import dataclass
-from typing import Any, Dict
+from dataclasses import dataclass, field
+from typing import Any, Dict, Tuple
 
+from ctlml_commons.util.entity_utils import separate_fields
 from ctlml_commons.util.num_utils import convert_floats
 
 
@@ -34,10 +35,20 @@ class Fundamentals:
     num_employees: int
     year_founded: int
     symbol: str
+    other: field(default_factory=dict)
+
+    def serialize(self) -> Dict[str, Any]:
+        return self.__dict__
 
     @classmethod
     def deserialize(cls, input_data: Dict[str, Any]) -> Fundamentals:
-        return Fundamentals(**cls.clean(input_data=input_data))
+        known, other = cls.separate(cls.clean(input_data=input_data))
+
+        return cls(**known, other=other)
+
+    @classmethod
+    def separate(cls, input_data: Dict[str, Any]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
+        return separate_fields(known_fields=cls.__dataclass_fields__.keys(), input_data=input_data)
 
     @classmethod
     def clean(cls, input_data: Dict[str, Any]) -> Dict[str, Any]:
