@@ -3,9 +3,9 @@ from datetime import datetime, timedelta
 from typing import Any, Dict, List, Optional
 
 import dateparser
+import holidays.countries.united_states
 import pytz
 from dateutil import parser
-import holidays.countries.united_states
 
 BASE_TZ = pytz.timezone(zone="US/Eastern")
 UPDATED_AT: str = "updated_at"
@@ -91,6 +91,19 @@ def time_to_str(a_date: datetime = to_est(), format_str: str = "%H%M") -> str:
     return a_date.strftime(format_str)
 
 
+def str_to_time(time_str: str, format_str: str = "%H%M") -> datetime:
+    """Provides a time from a string based representation.
+
+    Args:
+        time_str: time string
+        format_str: time format string
+
+    Returns:
+        A parsed time
+    """
+    return datetime.strptime(time_str, format_str)
+
+
 def readable_datetime_to_str(a_date: datetime = to_est(), format_str: str = "%Y-%m-%d %H:%M:00") -> str:
     """Provides a minute representation.
 
@@ -124,9 +137,9 @@ def timeoffset_as_str(seconds: int, a_datetime=to_est()) -> str:
 
 
 def timestamp_strs_for_window(
-        window: int,
-        seconds: int,
-        a_datetime: datetime = to_est(),
+    window: int,
+    seconds: int,
+    a_datetime: datetime = to_est(),
 ) -> List[str]:
     """For a start time, num of windows and length per window, produce time strings from start time to
     start time - (window * seconds).
